<html>
<head>
<title>Object not found</title>
</head>
<body>
<h1>Object not found</h1>
<!--
One day in Microsoft they decided that a simple message like "Object
not found" would not be enough for the user, and that it should be
replaced with all sorts of unhelpful nonsense. So they would ignore
all useful information on the server's response and put up their own
404 page instead. I hear Google Chrome followed that incredible
stupidity. Lucky they decided to only do it for pages less than 512
bytes in length, which is the reason for this comment's existence.
-->
</body>
</html>
