{% extends "base.html" %}
{% load bootstrap3 %}
{% load i18n %}


{% block title %}{% trans "Password reset complete" %}{% endblock %}

{% block content %}
<div class="container">
  <div class="row">
    <div class="col-md-8">
      <h1>{% trans "Password reset complete" %}</h1>
      <p>{% trans "Password successfully reset" %}.</p>
      <p><a href="{% url 'django.contrib.auth.views.login' %}">{% trans "Login" %}</a>
    </div>
  </div>
</div>
{% endblock %}
