{% extends "base.html" %}
{% load bootstrap3 %}
{% load i18n %}


{% block title %}{% trans "Registration complete" %}{% endblock %}

{% block content %}
<div class="container">
  <div class="row">
	<div class="col-md-8">
	  <h1>{% trans "Success, Please check your email" %}.</h1>
	  <p> {% trans "An activation email has been sent" %}.</p>
	</div>
  </div>
</div>
{% endblock %}
