{% extends "base.html" %}
{% load bootstrap3 %}
{% load i18n %}


{% block title %}{% trans "Password reset successful" %}{% endblock %}

{% block content %}
<div class="container">
  <div class="row">
    <div class="col-md-8">
      <h1>{% trans "Password has been reset" %}.</h1>
      <p>{% trans "An email with instructions for setting a new password has been sent" %}.</p>
    </div>
  </div>
</div>
{% endblock %}
